idna: Internationalized Domain Names in Applications (IDNA)
===========================================================

Description
-----------

Internationalized Domain Names in Applications (IDNA)

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/idna/

